<div align="center">

# Kayaku

> Power within little particles.

A powerful and flexible configuration solution.

[![codecov](https://codecov.io/gh/GraiaProject/kayaku/branch/master/graph/badge.svg?token=N02KA74USQ)](https://codecov.io/gh/GraiaProject/kayaku)
</div>

## License

This project is licensed under [MIT license](./LICENSE).
